Class: Azure::CognitiveServices::FormRecognizer::V1_0_preview::Models::ExtractedToken

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/1.0-preview/generated/azure_cognitiveservices_formrecognizer/models/extracted_token.rb

Overview

Canonical representation of single extracted text.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#bounding_boxArray<Float>

the location of the extracted text as a pair of cartesian co-ordinates. The co-ordinate pairs are arranged by top-left, top-right, bottom-right and bottom-left endpoints box with origin reference from the bottom-left of the page.

Returns:

  • (Array<Float>)

    Bounding box of the extracted text. Represents



24
25
26
# File 'lib/1.0-preview/generated/azure_cognitiveservices_formrecognizer/models/extracted_token.rb', line 24

def bounding_box
  @bounding_box
end

#confidenceFloat

Returns A measure of accuracy of the extracted text.

Returns:

  • (Float)

    A measure of accuracy of the extracted text.



27
28
29
# File 'lib/1.0-preview/generated/azure_cognitiveservices_formrecognizer/models/extracted_token.rb', line 27

def confidence
  @confidence
end

#textString

Returns String value of the extracted text.

Returns:

  • (String)

    String value of the extracted text.



16
17
18
# File 'lib/1.0-preview/generated/azure_cognitiveservices_formrecognizer/models/extracted_token.rb', line 16

def text
  @text
end

Class Method Details

.mapperObject

Mapper for ExtractedToken class as Ruby Hash. This will be used for serialization/deserialization.



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/1.0-preview/generated/azure_cognitiveservices_formrecognizer/models/extracted_token.rb', line 34

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'ExtractedToken',
    type: {
      name: 'Composite',
      class_name: 'ExtractedToken',
      model_properties: {
        text: {
          client_side_validation: true,
          required: false,
          serialized_name: 'text',
          type: {
            name: 'String'
          }
        },
        bounding_box: {
          client_side_validation: true,
          required: false,
          serialized_name: 'boundingBox',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'FloatElementType',
                type: {
                  name: 'Double'
                }
            }
          }
        },
        confidence: {
          client_side_validation: true,
          required: false,
          serialized_name: 'confidence',
          type: {
            name: 'Double'
          }
        }
      }
    }
  }
end